/* afidata.h */
/************************************************************************/
/* (C) Copyright IBM Corporation 1986.					*/
/************************************************************************/

/************************************************************************/
/* Definitions & declarations relevant to the AF Interface		*/
/*									*/
/*									*/
/* Compiler independent section '#include'd by compiler dependent       */
/* section.								*/
/*									*/
/* May be used with both Lattice C 3.00 large model ( -mls option),	*/
/* Microsoft C 3.00 with the /Ze option (any model),			*/
/* or the IBM C 1.00 compiler with /Ze option enabled (any model).	*/
/*									*/
/*									*/
/* #DEFINES beginning B4_ are specific to the 4-Plane display only	*/
/* #DEFINES beginning B8_ are specific to the 8-Plane display only	*/
/*									*/
/************************************************************************/

#define HLINE_DATA(S) struct { word length; coord_pr coords[S]; }
/* usage: HLINE_DATA(size) will give the following structure		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  coord_pr coords[size];						*/
/*  }									*/
/*									*/

#define HCLINE_DATA(S) struct { word length; coord_pr coords[S]; }
/* usage: HCLINE_DATA(size) will give the following structure		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  coord_pr coords[size];						*/
/*  }									*/
/*									*/

#define HRLINE_DATA(S) struct { word length; coord_pr coord1; rcoord_pr rcoords[S]; }
/* usage: HRLINE_DATA(size) will give the following structure		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  coord_pr coord1;							*/
/*  rcoord_pr rcoords[size];						*/
/*  }									*/
/*									*/

#define HCRLINE_DATA(S) struct { word length; rcoord_pr rcoords[S]; }
/* usage: HCRLINE_DATA(size) will give the following structure		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  rcoord_pr rcoords[size];						*/
/*  }									*/
/*									*/

#define HSCP_DATA struct { word length; coord_pr coord1; }
/* usage: HSCP_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  coord_pr coord1;							*/
/*  }									*/
/*									*/

/* There is no HBAR data						*/
/*									*/

#define HEAR_DATA struct { word length; byte flags; }
/* usage: HEAR_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte flags; 							*/
/*  }									*/
/*									*/

#define HSCOL_DATA struct { word length; long index; }
/* usage: HSCOL_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  long index; 							*/
/*  }									*/
/*									*/

/* following colours apply to the 4 plane display			*/
#define B4_RED	 0x000CL /* full red on B4    */
#define B4_GREEN 0x000AL /* full green on B4  */
#define B4_BLUE  0x0009L /* full blue  on B4  */
#define B4_WHITE (B4_RED | B4_GREEN | B4_BLUE)
#define B4_CYAN  (B4_GREEN | B4_BLUE)
#define B4_YELLO (B4_RED | B4_GREEN)
#define B4_MAGEN (B4_RED | B4_BLUE)

#define B4_R0	 0x004L  /* red bit 0 on B4 */
#define B4_B0	 0x001L  /* blue bit 0 on B4 */
#define B4_G0	 0x002L  /* green bit 0 on B4 */
#define B4_IN	 0x008L  /* hi Intensity on B4 */

/* following colours apply to the Brecon 8 plane model			*/
#define B8_RED	 0x0049L /* full red on B8    */
#define B8_GREEN 0x0092L /* full green on B8  */
#define B8_BLUE  0x0024L /* full blue  on B8  */
#define B8_WHITE (B8_RED | B8_GREEN | B8_BLUE)
#define B8_CYAN  (B8_GREEN | B8_BLUE)
#define B8_YELLO (B8_RED | B8_GREEN)
#define B8_MAGEN (B8_RED | B8_BLUE)

#define B8_R0	 0x001L  /* red bit 0 on B8 */
#define B8_R1	 0x008L  /* red bit 1 on B8 */
#define B8_R2	 0x040L  /* red bit 2 on B8 */
#define B8_B0	 0x004L  /* blue bit 0 on B8 */
#define B8_B1	 0x020L  /* blue bit 1 on B8 */
#define B8_G0	 0x002L  /* green bit 0 on B8 */
#define B8_G1	 0x010L  /* green bit 1 on B8 */
#define B8_G2	 0x080L  /* green bit 2 on B8 */

#define HOPEN_DATA struct { word length; byte oflags,mode,iflags; }
/* usage: HOPEN_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte oflags,							*/
/*	 mode,								*/
/*	 iflags;							*/
/*  }									*/
/*									*/
/*									*/

#define HSMX_DATA struct { word length; byte foremix; byte backmix; }
/* usage: HSMX_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte foremix;							*/
/*  byte backmix;							*/
/*  }									*/
/*									*/
#define MIX_NOC       0x00	/* No change to mix	*/
#define MIX_OR	      0x01	/* OR			*/
#define MIX_OVER      0x02	/* Overpaint		 */
#define MIX_XOR       0x04	/* Exclusive OR 	 */
#define MIX_LEAVE     0x05	/* Leave alone		 */
#define MIX_ADD       0x08	/* Add colour to screen  */
#define MIX_SUB       0x09	/* screen - colour	*/
#define MIX_MEAN      0x0B	/* average of screen & colour	*/

#define HSBCOL_DATA struct { word length; long index; }
/* usage: HSBCOL_DATA will give the following structure 		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  long index; 							*/
/*  }									*/
/*									*/

#define HSLT_DATA struct { word length; byte index, reserved; byte far *def; }
/* usage: HSLT_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte index; 							*/
/*  byte reserved;							*/
/*  byte far *def;							*/
/*  }									*/
/*									*/

#define HSLW_DATA struct { word length; byte index; }
/* usage: HSLW_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte index; 							*/
/*  }									*/
/*									*/

/* There is no HEGS data						*/
/*									*/


#define HSGQ_DATA struct { word length; word index; }
/* usage: HSGQ_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  word index; 							*/
/*  }									*/
/*									*/

#define HSCMP_DATA struct { word length; long col; byte function; }
/* usage: HSCMP_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  long col;								*/
/*  byte function;							*/
/*  }									*/
/*									*/

#define HINT_DATA struct { word length; long eventid; }
/* usage: HINT_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  long eventid;							*/
/*  }									*/
/*									*/

#define HSPATTO_DATA struct { word length; coord_pr coord1; }
/* usage: HSPATTO_DATA will give the following structure		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length,							*/
/*  coord_pr coord1;							*/
/*  }									*/
/*									*/

#define HSPATT_DATA struct { word length; byte width,height,flags,reserved; word img_length; byte far *image, far *colour; }
/* usage: HSPATT_DATA will give the following structure 		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte width, 							*/
/*	 height,							*/
/*	 flags, 							*/
/*	 reserved;							*/
/*  word img_length;							*/
/*  byte far *image,							*/
/*	 far *colour;							*/
/*  }									*/
/*									*/

#define HLDPAL_DATA struct { word length; byte pal_id,res1;int first,count;byte far *address; }
/* usage: HLDPAL_DATA will give the following structure 		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte pal_id,							*/
/*	 res1;								*/
/*  int first,								*/
/*	count;								*/
/*  byte far *address;							*/
/*  }									*/
/*									*/

#define HSHS_DATA struct { word length;int l,r,b,t; }
/* usage: HSHS_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  int l,								*/
/*	r,								*/
/*	b,								*/
/*	t;								*/
/*  }									*/
/*									*/

#define HBBW_DATA struct { word length,format,width,height; coord_pr coord; int l,t,w,h; }
/* usage: HBBW_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length,							*/
/*	format, 							*/
/*	width,								*/
/*	height, 							*/
/*  coord_pr coord;							*/
/*  int l,								*/
/*	t,								*/
/*	w,								*/
/*	h;								*/
/*  }									*/
/*									*/

#define HCBBW_DATA struct { word length,format,width,height,l,t,w,h; }
/* usage: HCBBW_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length,							*/
/*	format, 							*/
/*	width,								*/
/*	height, 							*/
/*	l,								*/
/*	t,								*/
/*	w,								*/
/*	h;								*/
/*  }									*/
/*									*/

#define HBBR_DATA struct { word length,format,width,height; byte plane,reserved; coord_pr coord; word l,t,w,h;}
/* usage: HBBR_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length,							*/
/*	format, 							*/
/*	width,								*/
/*	height, 							*/
/*  byte plane, 							*/
/*	 reserved;							*/
/*  coord_pr coord;							*/
/*  word l,								*/
/*	 t,								*/
/*	 w,								*/
/*	 h,								*/
/*  }									*/
/*									*/

#define HBBCHN_DATA struct { word length; byte far *address; int len; }
/* usage: HBBCHN_DATA will give the following structure 		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte far *address;							*/
/*  int len;								*/
/*  }									*/
/*									*/

#define HBBC_DATA struct { word length,format,width,height; byte plane,reserved; coord_pr source,dest; }
/* usage: HBBC_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length,							*/
/*	format, 							*/
/*	width,								*/
/*	height, 							*/
/*  byte plane, 							*/
/*	 reserved;							*/
/*  coord_pr source,							*/
/*	     dest;							*/
/*  }									*/
/*									*/

#define HSCOORD_DATA struct { word length; byte acformat,rcformat,ndimens; }
/* usage: HSCOORD_DATA will give the following structure		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte acformat,							*/
/*	 rcformat,							*/
/*	 ndimens;							*/
/*  }									*/
/*									*/

#define HQCOORD_DATA struct { word length; byte acformat,rcformat,ndimens,result; }
/* usage: HQCOORD_DATA will give the following structure		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte acformat,							*/
/*	 rcformat,							*/
/*	 ndimens,							*/
/*	 result;							*/
/*  }									*/
/*									*/

#define HSMODE_DATA struct { word length; byte scformat; }
/* usage: HSMODE_DATA will give the following structure 		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte scformat;							*/
/*  }									*/
/*									*/

#define HQMODE_DATA struct { word length; byte mode; byte clvl[2]; byte atype,dtype,ac_w,ac_h,nplanes;word width,height,h_pitch,v_pitch;byte moco,n_i_lvls; }
/* usage: HQMODE_DATA will give the following structure 		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte mode;								*/
/*  byte clvl[2];							*/
/*  byte atype, 							*/
/*	 dtype, 							*/
/*	 ac_w,								*/
/*	 ac_h,								*/
/*	 nplanes;							*/
/*  word width, 							*/
/*	 height,							*/
/*	 h_pitch,							*/
/*	 v_pitch;							*/
/*  byte moco,								*/
/*	 n_i_lvls;							*/
/*  }									*/
/*									*/

#define HQMODES_DATA struct { word length; byte atype,modes[32]; }
/* usage: HQMODES_DATA will give the following structure		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  byte atype, 							*/
/*	 modes[32];							*/
/*  }									*/
/*									*/

#define HQDPS_DATA struct { word length; int size, stack, palbufsize; }
/* usage: HQDPS_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  int size,								*/
/*	stack,								*/
/*	palbufsize;							*/
/*  }									*/
/*									*/

#define HRECT_DATA struct { word length; coord_pr coord; int width,height; }
/* usage: HRECT_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  coord_pr coord;							*/
/*  int width,								*/
/*	height; 							*/
/*  }									*/
/*									*/

#define HSBP_DATA struct { word length; longword grupdate, alupdate, display; }
/* usage: HSBP_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  longword grupdate,							*/
/*	     alupdate,							*/
/*	     display;							*/
/*  }									*/
/*									*/

#define HCLOSE_DATA struct { word length; word flags; }
/* usage: HCLOSE_DATA will give the following structure 		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  word flags; 							*/
/*  }									*/
/*									*/
/*									*/

/*									*/

/* There is no HESC data						*/
/*									*/

#define HXLATE_DATA struct { word length; longword table[8]; }
/* usage: HXLATE_DATA will give the following structure 		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  longword table[8];							*/
/*  }									*/
/*									*/

struct CharSetDef   /* Character Set Definition block			*/
{
  byte reserve1;	/* reserved					*/
  byte csettype;	/* Char set type  0 - image/triplane image	*/
			/*		  3 - short stroke vector	*/
  long reserve2;	/* reserved					*/
  byte reserve3;	/* reserved					*/
  byte cellwidth;	/* character cell width (pels)			*/
  byte cellheight;	/* character cell height (pels) 		*/
  byte reserve4;	/* reserved					*/
  word cellnbytes;	/* no. bytes per cell definition (ceil(cx*cy/8))*/
  word flags;		/* Flags as follows				*/
#define MULTIPLANE 0x4000	/* single or multi plane		*/
#define PROPSPACE  0x2000	/* single or multi plane		*/
  word far *indextbl;	/* address of index table			*/
  byte far *enveltbl;	/* address of envelope table			*/
  byte cdpt1st; 	/* initial code point				*/
  byte cdptlast;	/* final code point				*/
  byte far *chardef1;	/* address of character definition 1		*/
  word reserve5;	/* reserved					*/
  byte far *chardef2;	/* address of character definition 2		*/
  word reserve6;	/* reserved					*/
  byte far *chardef3;	/* address of character definition 3		*/
};

#define HSCS_DATA struct { word length; struct CharSetDef far *address; }
/* usage: HSCS_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  struct CharSetDef far *address;					*/
/*  }									*/
/*									*/

#define HCHST_DATA(L) struct { word length; coord_pr coord; char string[L]; }
/* usage: HCHST_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  coord_pr coord;							*/
/*  char string[L];							*/
/*  }									*/
/*									*/

#define HCCHST_DATA(L) struct { word length; char string[L]; }
/* usage: HCCHST_DATA will give the following structure 		*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  char string[L];							*/
/*  }									*/
/*									*/

#define ABLKMFI_DATA struct { word length; byte colm,row,across,down; byte far *chars; byte width; }
/* usage: ABLKMFI_DATA will give the following structure	      */
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* byte colm,								*/
/*	row,								*/
/*	across, 							*/
/*	down;								*/
/* byte far *chars;							*/
/* byte width;								*/
/* }									*/
/*									*/

#define ABLKCGA_DATA struct { word length; byte colm,row,across,down; byte far *chars; byte width,hilite; }
/* usage: ABLKCGA_DATA will give the following structure	      */
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* byte colm,								*/
/*	row,								*/
/*	across, 							*/
/*	down;								*/
/* byte far *chars;							*/
/* byte width,								*/
/*	hilite; 							*/
/* }									*/
/*									*/

#define AERASE_DATA struct { word length; byte colm,row,across,down,colour; }
/* usage: AERASE_DATA will give the following structure 		*/
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* byte colm,								*/
/*	row,								*/
/*	across, 							*/
/*	down,								*/
/*	colour; 							*/
/* }									*/
/*									*/

#define ASCROLL_DATA struct { word length; byte sor_colm,sor_row,across,down,des_colm,des_row; }
/* usage: ASCROLL_DATA will give the following structure		*/
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* byte sor_colm,							*/
/*	sor_row,							*/
/*	across, 							*/
/*	down,								*/
/*	des_colm;							 */
/*	des_row;							*/
/* }									*/
/*									*/

#define ACURSOR_DATA struct { word length; byte colm,row; }
/* usage: ACURSOR_DATA will give the following structure		*/
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* byte colm,								*/
/*	row;								*/
/* }									*/
/*									*/

#define ASCUR_DATA struct { word length; byte start,stop,attr; }
/* usage: ASCUR_DATA will give the following structure			*/
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* byte start,								*/
/*	stop,								*/
/*	attr;								*/
/* }									*/
/*									*/

#define ASFONT_DATA struct { word length; byte font,res; struct CharSetDef far *address; }
/* usage: ASFONT_DATA will give the following structure 		*/
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* byte font,								*/
/*	res;								*/
/* struct CharSetDef far *address;					*/
/* }									*/
/*									*/

#define AXLATE_DATA struct { word length; longword foretable[16],backtable[16]; }
/* usage: AXLATE_DATA will give the following structure 		*/
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* longword foretable[16],						*/
/*	backtable[16];							*/
/* }									*/
/*									*/

#define HINIT_DATA struct { word length; word segment; }
/* usage: HINIT_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  word segment;							*/
/*  }									*/
/*									*/

#define HSYNC_DATA struct { word length; word segment; }
/* usage: HSYNC_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  word segment;							*/
/*  }									*/
/*									*/

#define HMRK_DATA(S) struct { word length; coord_pr coords[S];}
/* usage: HMRK_DATA will give the following structure			*/
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* coord_pr coords[S]							*/
/* }									*/
/*									*/

#define HCMRK_DATA(S) struct { word length; coord_pr coords[S];}
/* usage: HCMRK_DATA will give the following structure			*/
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* coord_pr coords[S]							*/
/* }									*/
/*									*/

#define HSMARK_DATA struct {word length; byte width, height, flags, res; int imlen; byte far *image; byte far *colour; }
/* usage: HSMARK_DATA will give the following structure 		*/
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* byte width,								*/
/*	height, 							*/
/*	flags,								*/
/*	res;								*/
/* int	imlen;								*/
/* byte far *image;							*/
/* byte far *colour;							*/
/* }									*/
/*									*/

/* There is no HSLPC data						*/
/*									*/

/* There is no HRLPC data						*/
/*									*/

#define HQCP_DATA struct { word length; coord_pr coord1; }
/* usage: HQCP_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  coord_pr coord1;							*/
/*  }									*/
/*									*/


#define HQDFPAL_DATA struct {word length; long table[16]; }
/* usage: HQDFPAL_DATA will give the following structure		*/
/*									*/
/* struct								*/
/* {									*/
/* word length; 							*/
/* long table[16];							*/
/* }									*/
/*									*/

#define HSPAL_DATA struct { word length; char paldata[769]; }
/* usage: HSPAL_DATA will give the following structure			*/
/*									*/
/*  struct								*/
/*  {									*/
/*  word length;							*/
/*  char paldata[769];							*/
/*  }									*/
/*									*/

#define HRPAL_DATA HSPAL_DATA
/* usage: HRPAL uses an HSPAL data block				*/
/*									*/

/* Font file definition 						*/
/* This is the layout of the font file header				*/
/* All the address fields within the CSD's (Character Set Definition)   */
/* are offsets within the file. To these should be added the address	*/
/* at which the font is loaded to give the correct values.		*/
/*									*/
struct FontFileDefn
{
  int no_pages; /* no of code pages in the file (size of page_array)	*/
  int def_page; /* default page index (into page_array) 		*/
  int alt_page; /* alternate default page index (into page_array)	*/
  struct
  {
    char code_page_id[4];	/* code page id 			*/
    int  csd_offset;		/* offset within file of CSD block	*/
  } page_array[1];	/* array of code page ID's and CSD offsets      */
};
